smooth.pred <- function(data, rows) {
  mod <- loess(prc ~ t, data=data, span=0.2)
  if (missing(rows))    
    grid <- data.frame(t = data$t)
  else
    grid <- data.frame(t = seq(min(data$t), max(data$t), length=rows))
  grid$epoch = epoch(grid$t)
  prc <- stats::predict(mod, grid)
  prc
}

proc.data <- function(data) {
  # Strip zero-value rows
  data <- data[data$num != 0,]

  # Transform temporal scale
  data$epoch <- epoch(data$t)

  span = max(data$num) - min(data$num)
  data$prc <- (data$num - min(data$num)) / span * 100
  data
}

proc.data.pred <- function(data, alldata) {
  data <- proc.data(data)
  data$prc.pred <- smooth.pred(data)

  # Now create an estimate of the overall distribution, adjusted to
  # match the maxima/minima of the faceted estimate.
  data$prc.pred.abs <- smooth.pred(alldata, nrow(data))

  pred.min <- min(data$prc.pred)
  pred.range <- max(data$prc.pred) - pred.min
  pred.abs.range <- max(data$prc.pred.abs) - min(data$prc.pred.abs)
  
  # Align total prediction with faceted one:
  data$prc.pred.abs <- data$prc.pred.abs - min(data$prc.pred.abs)
  data$prc.pred.abs <- data$prc.pred.abs * (pred.range / pred.abs.range)
  data$prc.pred.abs <- data$prc.pred.abs + pred.min
  
  data
}

proc.data.pred.we <- function(data) {
  data <- proc.data.pred(data, data.all.we)
  data
}

proc.data.pred.wd <- function(data) {
  data <- proc.data.pred(data, data.all.wd)
  data
}

data.all.wd <- read.csv('activity_all.wd.data')
data.all.we <- read.csv('activity_all.we.data')

data.tag.wd <- read.csv('activity_tag.wd.data', as.is=TRUE)
data.tag.we <- read.csv('activity_tag.we.data', as.is=TRUE)

# Build a custom factor:
data.tag.wd$tag = factor(data.tag.wd$tag, labels=c('< 18', '18-25', '26-35', '36-45', '46-55', '> 55'))
data.tag.we$tag = factor(data.tag.we$tag, labels=c('< 18', '18-25', '26-35', '36-45', '46-55', '> 55'))

data.all.wd <- proc.data(data.all.wd)
data.all.we <- proc.data(data.all.we)

data.tag.wd <- do.call('rbind', by(data.tag.wd, data.tag.wd$tag, proc.data.pred.wd))
data.tag.we <- do.call('rbind', by(data.tag.we, data.tag.we$tag, proc.data.pred.we))

# Now build data frames that combine weekday and weekend:
data.tag.wd$dow <- rep('weekday', nrow(data.tag.wd))
data.tag.we$dow <- rep('weekend', nrow(data.tag.we))
data.tag <- rbind(data.tag.wd, data.tag.we)

# Plot the overall one:
p <- ggplot() +
  geom_line(data=data.all.wd, aes(epoch, prc), color='gray50') +
  geom_line(data=data.all.we, aes(epoch, prc), color='gray80') +
  geom_smooth(data=data.all.wd, aes(epoch, prc), color='darkblue', method='loess', span=0.2) +
  geom_smooth(data=data.all.we, aes(epoch, prc), color='blue', method='loess', span=0.2) +
  labs(x='Time of day', y='% of users') +
  scale_x_datetime(format='%H', major='6 hours', minor='2 hours')
ggsave('testpilot-time-of-day.dow.png', plot=p)

# Plot the facets:
p <- ggplot(data.tag, aes(epoch, prc)) +
  geom_line(color='darkgray') +
  geom_line(mapping=aes(epoch, prc.pred.abs), color='blue') +
  geom_line(mapping=aes(epoch, prc.pred), color='darkblue') +
  labs(x='Time of day', y='% of users') +
  scale_x_datetime(format='%H', major='6 hours', minor='2 hours') +
  facet_grid(tag ~ dow)
ggsave('testpilot-time-of-day-facets.dow.png', plot=p)

#  geom_smooth(data=data.all, mapping=aes(epoch, prc), color='blue') +
#  geom_smooth(color='darkblue', ) +
